@@ -1,48 +1,38 @@
 -- | [/QUICK START:/]
 --
--- You can either run the @cabal-debian --debianize@, or
+-- You can either run @cabal-debian@, or
 -- for more power and flexibility you can put a @Debianize.hs@ script in
 -- the package's @debian@ subdirectory.
--- 'Debian.Debianize.CabalInfo' value and pass it to the
--- 'Debian.Debianize.debianize' function.  The
--- 'Debian.Debianize.callDebianize' function retrieves extra arguments
--- from the @CABALDEBIAN@ environment variable and calls
--- 'Debian.Debianize.debianize' with the build directory set as it
--- would be when the packages is built by @dpkg-buildpackage@.
 --
 -- To see what your debianization would produce, or how it differs
 -- from the debianization already present:
 --
--- > % cabal-debian --debianize -n
+-- > % cabal-debian -n
 --
 -- This is equivalent to the library call
 --
--- > % ghc -e 'Debian.Debianize.callDebianize ["-n"]'
+-- > % ghc -e 'System.Environment.withArgs ["-n"] $ Debian.Debianize.performDebianization Debian.Debianize.debianDefaults'
 --
 -- To actually create the debianization and then build the debs,
 --
--- > % ghc -e 'Debian.Debianize.callDebianize []'
+-- > % ghc -e 'Debian.Debianize.performDebianization Debian.Debianize.debianDefaults'
 -- > % sudo dpkg-buildpackage
 --
--- At this point you may need to modify Cabal.defaultFlags to achieve
--- specific packaging goals.  Create a module for this in debian/Debianize.hs:
+-- At this point you may need a script to achieve specific packaging
+-- goals.  Put this this in debian/Debianize.hs:
 --
--- > import Data.Lens.Lazy
--- > import Data.Map as Map (insertWith)
--- > import Data.Set as Set (union, singleton)
+-- > import Control.Lens
+-- > import Data.Map as Map
+-- > import Data.Set as Set
 -- > import Debian.Relation (BinPkgName(BinPkgName), Relation(Rel))
--- > import Debian.Debianize (defaultAtoms, depends, debianization, writeDebianization)
--- > main = debianization "." defaultAtoms >>=
--- >        return . modL depends (insertWith union (BinPkgName "cabal-debian") (singleton (Rel (BinPkgName "debian-policy") Nothing Nothing))) >>=
--- >        writeDebianization "."
+-- > import Debian.Debianize
+-- > main = performDebianization $ do
+-- >   debianDefaults
+-- >   (debInfo . binaryDebDescription (BinPkgName "cabal-debian") . relations . depends) %= (++ (rels "apt-file, debian-policy, debhelper, haskell-devscripts (>= 0.8.19)"))
 --
 -- Then to test it,
 --
--- > % CABALDEBIAN='["-n"]' runhaskell debian/Debianize.hs
---
--- or equivalently
---
--- > % ghc -e 'Debian.Debianize.runDebianize ["-n"]'
+-- > % runhaskell debian/Debianize.hs -n
 --
 -- and to run it for real:
 --
@@ -97,7 +87,7 @@ module Debian.Debianize
     , module Debian.Debianize.InputDebian
     , module Debian.Debianize.InputCabal
       -- * Finish computing the debianization and output the result
-    , module Debian.Debianize.Finalize
+    -- , module Debian.Debianize.Finalize
     , module Debian.Debianize.Output
       -- * Utility functions
     , module Debian.Debianize.Prelude
@@ -113,12 +103,12 @@ import Debian.Debianize.CopyrightDescription
 import Debian.Debianize.DebInfo -- (Atom(..), atomSet, changelog, compat, control, copyright, DebInfo, file, flags, install, installCabalExec, installCabalExecTo, installData, installDir, installInit, installTo, intermediateFiles, link, logrotateStanza, makeDebInfo, postInst, postRm, preInst, preRm, rulesFragments, rulesHead, rulesIncludes, rulesSettings, sourceFormat, warning, watch, apacheSite, backups, buildDir, comments, debVersion, execMap, executable, extraDevDeps, extraLibMap, InstallFile(..), maintainerOption, missingDependencies, noDocumentationLibrary, noProfilingLibrary, official, omitLTDeps, omitProfVersionDeps, revision, Server(..), serverInfo, Site(..), sourceArchitectures, sourcePackageName, uploadersOption, utilsPackageNameBase, website, xDescription, overrideDebianNameBase)
 import Debian.Debianize.DebianName (mapCabal, splitCabal, remapCabal)
 import Debian.Debianize.Details (debianDefaults)
-import Debian.Debianize.Finalize (debianize)
+--import Debian.Debianize.Finalize (debianize)
 import Debian.Debianize.Goodies -- (doBackups, doExecutable, doServer, doWebsite, tightDependencyFixup)
 import Debian.Debianize.InputDebian (inputChangeLog, inputDebianization, inputDebianizationFile)
 import Debian.Debianize.InputCabal (inputCabalization)
 import Debian.Debianize.Monad (CabalM, CabalT, evalCabalM, evalCabalT, execCabalM, execCabalT, runCabalM, runCabalT, DebianT, execDebianT, evalDebianT, liftCabal)
-import Debian.Debianize.Output (compareDebianization, describeDebianization, finishDebianization, runDebianizeScript, validateDebianization, writeDebianization)
+import Debian.Debianize.Output (compareDebianization, describeDebianization, finishDebianization, performDebianization, runDebianizeScript, validateDebianization, writeDebianization)
 import Debian.Debianize.Prelude (buildDebVersionMap, debOfFile, dpkgFileMap, withCurrentDirectory, (.?=))
 import Debian.Debianize.SourceDebDescription
 import Debian.Debianize.VersionSplits (DebBase(DebBase))
