@@ -30,7 +30,7 @@ import Debian.Debianize.CabalInfo (CabalInfo, debInfo)
 import qualified Debian.Debianize.DebInfo as D
 import Debian.Debianize.Files (debianizationFileMap)
 import Debian.Debianize.InputDebian (inputDebianization)
-import Debian.Debianize.Monad (DebianT, CabalT, evalDebianT, evalCabalT)
+import Debian.Debianize.Monad (DebianT, CabalT, evalDebian, evalCabalT)
 import Debian.Debianize.Prelude (indent, replaceFile, zipMaps)
 import Debian.Debianize.Finalize (debianize)
 import Debian.Debianize.Optparse
@@ -38,7 +38,7 @@ import Debian.Debianize.BinaryDebDescription as B (canonical, package)
 import qualified Debian.Debianize.SourceDebDescription as S
 import Debian.Pretty (ppShow, ppPrint)
 import Prelude hiding (unlines, writeFile)
-import System.Directory (createDirectoryIfMissing, doesFileExist, getPermissions, Permissions(executable), setPermissions)
+import System.Directory (createDirectoryIfMissing, doesFileExist, getCurrentDirectory, getPermissions, Permissions(executable), setPermissions)
 import System.Exit (ExitCode(ExitSuccess))
 import System.FilePath ((</>), takeDirectory)
 import System.IO (hPutStrLn, stderr)
@@ -56,26 +56,21 @@ import System.Posix.Env (setEnv)
 -- in the debian subdirectory of this library.
 runDebianizeScript :: [String] -> IO Bool
 runDebianizeScript args =
-    -- getEnv "HOME" >>= \ home ->
+    getCurrentDirectory >>= \here ->
     doesFileExist "debian/Debianize.hs" >>= \ exists ->
     case exists of
       False -> return False
       True -> do
-        let args' = ["debian/Debianize.hs"] ++ args
-        putEnvironmentArgs args
-        hPutStrLn stderr (showCommandForUser "runhaskell" args')
+        -- By default runhaskell looks for source in ., we will also look
+        -- in src.  Better would be to see where the cabal file looks.
+        let args' = ["-i.:src", "debian/Debianize.hs"] ++ args
+        hPutStrLn stderr ("running external debianization script in " ++ show here ++ ":\n  " ++ showCommandForUser "runhaskell" args')
         result <- readProcessWithExitCode "runhaskell" args' ""
         case result of
           (ExitSuccess, _, _) -> return True
-          (code, out, err) -> error ("runDebianizeScript: " ++ showCommandForUser "runhaskell" args' ++ " -> " ++ show code ++
+          (code, out, err) -> error (" external debianization script failed:\n  " ++ showCommandForUser "runhaskell" args' ++ " -> " ++ show code ++
                                      "\n stdout: " ++ show out ++"\n stderr: " ++ show err)
 
--- | Insert a value for CABALDEBIAN into the environment that the
--- withEnvironment* functions above will find and use.  E.g.
--- putEnvironmentFlags ["--dry-run", "--validate"] (debianize defaultFlags)
-putEnvironmentArgs :: [String] -> IO ()
-putEnvironmentArgs fs = setEnv "CABALDEBIAN" (show fs) True
-
 -- | Perform whole debianization. You provide your customization,
 -- this function does everything else.
 performDebianization :: CabalT IO () -> IO ()
@@ -99,8 +94,8 @@ finishDebianization = zoom debInfo $
          _ | view (D.flags . dryRun) new ->
                do inputDebianization
                   old <- get
-                  diff <- liftIO $ compareDebianization old new
-                  liftIO $ putStrLn ("Debianization (dry run):\n" ++ if null diff then "  No changes\n" else diff)
+                  let diff = compareDebianization old new
+                  liftIO $ putStrLn ("Debianization (dry run):\n" ++ if null diff then "  No changes\n" else show diff)
          _ -> writeDebianization
 
 
@@ -123,11 +118,11 @@ describeDebianization =
 
 -- | Compare the old and new debianizations, returning a string
 -- describing the differences.
-compareDebianization :: D.DebInfo -> D.DebInfo -> IO String
+compareDebianization :: D.DebInfo -> D.DebInfo -> [String]
 compareDebianization old new =
-    do oldFiles <- evalDebianT debianizationFileMap (canonical old)
-       newFiles <- evalDebianT debianizationFileMap (canonical new)
-       return $ concat $ Map.elems $ zipMaps doFile oldFiles newFiles
+    let oldFiles = evalDebian debianizationFileMap (canonical old)
+        newFiles = evalDebian debianizationFileMap (canonical new) in
+    elems $ zipMaps doFile oldFiles newFiles
     where
       doFile :: FilePath -> Maybe Text -> Maybe Text -> Maybe String
       doFile path (Just _) Nothing = Just (path ++ ": Deleted\n")
